@@ -1,15 +1,16 @@
 # pylint: disable=E0611
 """Declares :class:`Blob`."""
-import json
-
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from unimatrix.lib import timezone
 
+from .base import BaseBlob
 
-class Blob(models.Model):
+
+class Blob(models.Model, BaseBlob):
     """Maintains information about blobs used by an application."""
+    ObjectDoesNotExist = ObjectDoesNotExist
 
     #: SHA-256 hash of the blob content. If the :class:`Blob` is encrypted,
     #: the hash of the plain text.
@@ -61,41 +62,6 @@ class Blob(models.Model):
         db_column='labels'
     )
 
-    def is_encrypted(self):
-        """Return a boolean indicating if the :class:`Blob` is encrypted."""
-        try:
-            return self.ciphertext is not None
-        except ObjectDoesNotExist:
-            return False
-
-    def get_ciphertext(self, buf):
-        """Return a :class:`~unimatrix.ext.crypto.CipherText` instance
-        with the parameters used when encrypting this :class:`Blob`.
-        """
-        if not self.is_encrypted():
-            raise TypeError("Blob is not encrypted.")
-        return self.ciphertext.get_ciphertext(buf)
-
-    def get_key_id(self):
-        """Return an integer identifying the :class:`BlobEncryptionKey` that
-        was used to encrypt this :class:`Blob`, or ``None`` if it is not
-        encrypted.
-        """
-        return self.ciphertext.using_id if self.is_encrypted() else None
-
-    def setlabels(self, labels):
-        """Sets the labels on the :class:`Blob` instance."""
-        if isinstance(labels, str):
-            labels = json.loads(labels)
-        self.labels = labels
-
-    def getlabels(self):
-        """Return the labels specified for this :class:`Blob`."""
-        labels = self.labels
-        if isinstance(labels, str):
-            labels = json.loads(labels)
-        return labels
-
     __module__ = 'unimatrix.ext.octet.models'
 
     class Meta: # pylint: disable=C0115,R0903
